==> nextcloud-29.0.15.tar.bz2: nextcloud/apps/text/l10n/ka.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "The file was uploaded",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "The uploaded file exceeds the upload_max_filesize directive in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form",
    "The file was only partially uploaded" : "The file was only partially uploaded",
    "No file was uploaded" : "No file was uploaded",
    "Missing a temporary folder" : "Missing a temporary folder",
    "Could not write file to disk" : "Could not write file to disk",
    "A PHP extension stopped the file upload" : "A PHP extension stopped the file upload",
    "No file uploaded or file size exceeds maximum of %s" : "No file uploaded or file size exceeds maximum of %s",
    "New text file" : "New text file",
    "File not found" : "File not found",
    "Text" : "Text",
    "Translate" : "Translate",
    "Delete task" : "Delete task",
    "Reload" : "Reload",
    "Guest" : "Guest",
    "guest" : "guest",
    "Saving …" : "Saving …",
    "Saved" : "Saved",
    "Keyboard shortcuts" : "Keyboard shortcuts",
    "Enter" : "Enter",
    "Shift" : "Shift",
    "Quoted text" : "Quoted text",
    "Link" : "Link",
    "Smart picker" : "Smart picker",
    "Action" : "Action",
    "Undo" : "Undo",
    "Cannot copy, please copy the link manually" : "Cannot copy, please copy the link manually",
    "Save changes" : "Save changes",
    "Cancel" : "Cancel",
    "URL" : "URL",
    "Formatting help" : "Formatting help",
    "Translate from" : "Translate from",
    "Select language" : "Select language",
    "to" : "to",
    "Translate to" : "Translate to",
    "Replace" : "Replace",
    "Upload" : "Upload",
    "Edit" : "Edit",
    "Copy code block" : "Copy code block",
    "Source code" : "Source code",
    "Done" : "Done",
    "Headings" : "Headings",
    "Lists" : "Lists",
    "Details" : "Details",
    "Command" : "Command",
    "Ctrl" : "Ctrl",
    "Formatting" : "Formatting",
    "Select file or folder to link to" : "Select file or folder to link to",
    "Info" : "Info",
    "Warning" : "Warning"
},
"nplurals=2; plural=(n!=1);");

==> nextcloud-31.0.9.tar.bz2: nextcloud/apps/text/l10n/ka.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "The file was uploaded",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "The uploaded file exceeds the upload_max_filesize directive in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form",
    "The file was only partially uploaded" : "The file was only partially uploaded",
    "No file was uploaded" : "No file was uploaded",
    "Missing a temporary folder" : "Missing a temporary folder",
    "Could not write file to disk" : "Could not write file to disk",
    "A PHP extension stopped the file upload" : "A PHP extension stopped the file upload",
    "No file uploaded or file size exceeds maximum of %s" : "No file uploaded or file size exceeds maximum of %s",
    "New text file" : "New text file",
    "File not found" : "File not found",
    "Text" : "Text",
    "Nextcloud Assistant" : "Nextcloud-ის ასისტენტი",
    "Translate" : "Translate",
    "Delete task" : "Delete task",
    "Reload" : "Reload",
    "Enter your name" : "Enter your name",
    "Guest" : "Guest",
    "guest" : "guest",
    "Saving …" : "Saving …",
    "Saved" : "Saved",
    "Keyboard shortcuts" : "Keyboard shortcuts",
    "Enter" : "Enter",
    "Shift" : "Shift",
    "Quoted text" : "Quoted text",
    "Link" : "Link",
    "Smart picker" : "Smart picker",
    "Action" : "Action",
    "Undo" : "Undo",
    "Cannot copy, please copy the link manually" : "Cannot copy, please copy the link manually",
    "Save changes" : "Save changes",
    "Cancel" : "Cancel",
    "URL" : "URL",
    "Formatting help" : "Formatting help",
    "Translate from" : "Translate from",
    "Select language" : "Select language",
    "to" : "to",
    "Translate to" : "Translate to",
    "Replace" : "Replace",
    "Upload" : "Upload",
    "Edit" : "Edit",
    "Copy code block" : "Copy code block",
    "Source code" : "Source code",
    "Done" : "Done",
    "Headings" : "Headings",
    "Lists" : "Lists",
    "Details" : "Details",
    "Command" : "Command",
    "Ctrl" : "Ctrl",
    "Formatting" : "Formatting",
    "Select file or folder to link to" : "Select file or folder to link to",
    "Choose" : "Choose",
    "Choose {file}" : "Choose {file}",
    "Info" : "Info",
    "Warning" : "Warning"
},
"nplurals=2; plural=(n!=1);");
